API Reference
=============

The ``pycohortflow`` package is organised into two modules.

.. list-table::
   :widths: 30 70
   :header-rows: 0

   * - :doc:`api_cfd`
     - The main :func:`~pycohortflow.plot_cohort_flow_diagram` function
       that renders a cohort flow diagram from a list of steps.
   * - :doc:`api_cfd_util`
     - Colour utilities, text wrapping, configuration loading, and other
       internal helpers.

.. toctree::
   :maxdepth: 2
   :hidden:

   api_cfd
   api_cfd_util
